@@ -1,6 +1,5 @@
 efast_netlogo_run_Analysis<-function(FILEPATH,MEASURES,PARAMETERS,NUMCURVES,NUMSAMPLES,OUTPUTMEASURES_TO_TTEST,TTEST_CONF_INT,
-						GRAPH_FLAG,CURVERESULTSFILENAME,EFASTRESULTFILENAME,
-						TIMEPOINTS,TIMEPOINTSCALE)
+						GRAPH_FLAG,EFASTRESULTFILENAME,TIMEPOINTS,TIMEPOINTSCALE)
 {
 	# Check the parameter and measures strings
 	PARAMETERS<-table_header_check(PARAMETERS)
@@ -8,6 +7,5 @@ efast_netlogo_run_Analysis<-function(FILEPATH,MEASURES,PARAMETERS,NUMCURVES,NUMS
 
 	# Call the spartan function
 	efast_run_Analysis(FILEPATH,MEASURES,PARAMETERS,NUMCURVES,NUMSAMPLES,OUTPUTMEASURES_TO_TTEST,TTEST_CONF_INT,
-				GRAPH_FLAG,CURVERESULTSFILENAME,EFASTRESULTFILENAME,
-				TIMEPOINTS,TIMEPOINTSCALE)
+				GRAPH_FLAG,EFASTRESULTFILENAME,TIMEPOINTS,TIMEPOINTSCALE)
 }
